"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const provider_1 = require("../src/provider");
const axios_1 = __importDefault(require("axios"));
const exports_1 = require("object-collection/exports");
const endpoint = "https://blockchain.info/ticker";
module.exports = (0, provider_1.defineCpkProvider)(() => ({
    name: "blockchain.info",
    coinsSupported: ["BTC"],
    currenciesSupported: [
        "AUD",
        "BRL",
        "CAD",
        "CHF",
        "CLP",
        "CNY",
        "CZK",
        "DKK",
        "EUR",
        "GBP",
        "HKD",
        "HRK",
        "HUF",
        "INR",
        "ISK",
        "JPY",
        "KRW",
        "NZD",
        "PLN",
        "RON",
        "RUB",
        "SEK",
        "SGD",
        "THB",
        "TRY",
        "TWD",
        "USD"
    ],
    async getPrice(pair, currency) {
        try {
            // Get data from endpoint
            const res = await axios_1.default.get(endpoint);
            // Use object-collection to get the price
            let data = (0, exports_1.Obj)(res.data);
            if (data.has(`${currency}[15m]`)) {
                return data.get(`${currency}[15m]`);
            }
        }
        catch (e) {
            throw new Error(`Error fetching price from ${endpoint}`);
        }
        throw new Error(`No data for ${currency} in ${this.name}`);
    },
    async getPrices(pairs) {
        const result = {};
        try {
            const res = await axios_1.default.get(endpoint);
            let data = (0, exports_1.Obj)(res.data);
            for (let pair of pairs) {
                const { coin, currency } = pair;
                if (data.has(`${currency}[15m]`)) {
                    result[coin + "/" + currency] = data.get(`${currency}[15m]`);
                }
            }
        }
        catch (e) {
            console.log(e);
            throw new Error(`Error fetching price from ${endpoint}`);
        }
        return result;
    }
}));
