"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const provider_1 = require("../src/provider");
const axios_1 = __importDefault(require("axios"));
module.exports = (0, provider_1.defineCpkProvider)((config) => {
    if (!config)
        throw new Error("CoinMarketCap requires a config object");
    let baseUrl = "https://pro-api.coinmarketcap.com";
    return {
        name: "coinmarketcap",
        coinsSupported: "any",
        currenciesSupported: "any",
        async getPrice(coin, currency) {
            const endpoint = `${baseUrl}/v2/tools/price-conversion`;
            try {
                const { data } = await axios_1.default.get(endpoint, {
                    params: {
                        symbol: coin,
                        convert: currency,
                        amount: 1
                    },
                    headers: {
                        "X-CMC_PRO_API_KEY": config.apiKey
                    }
                });
                // Destructure the data
                const quote = data.data[0].quote[currency];
                // Return the price.
                return quote.price;
            }
            catch (e) {
                throw new Error(`Error fetching price from ${endpoint}`);
            }
        },
        async getPrices(pairs) {
            var _a;
            const endpoint = `${baseUrl}/v2/cryptocurrency/quotes/latest`;
            let data = undefined;
            const result = {};
            try {
                const res = await axios_1.default.get(endpoint, {
                    params: {
                        symbol: pairs.map((p) => p.coin).join(","),
                        convert: pairs.map((p) => p.currency).join(",")
                    },
                    headers: {
                        "X-CMC_PRO_API_KEY": config.apiKey
                    }
                });
                data = res.data.data;
            }
            catch (e) {
                console.log((_a = e.response) === null || _a === void 0 ? void 0 : _a.data);
            }
            if (!data)
                throw new Error(`Error fetching price from ${endpoint}`);
            for (const pair of pairs) {
                if (!data.hasOwnProperty(pair.coin))
                    throw new Error(`Coin ${pair.coin} not found`);
                const items = data[pair.coin];
                const pairString = `${pair.coin}/${pair.currency}`;
                for (const item of items) {
                    if (item.quote.hasOwnProperty(pair.currency)) {
                        result[pairString] = item.quote[pair.currency].price;
                    }
                }
                if (!result.hasOwnProperty(pairString))
                    throw new Error(`Pair ${pairString} not found`);
            }
            return result;
        }
    };
});
